########################################
Underwater Acoustics Analysis User Guide
########################################

.. role:: python(code)
   :language: python

.. default-literal-role:: python

.. toctree::
   :caption: Getting Started
   :maxdepth: 1

   installing

.. toctree::
    :caption: Examples and Tutorials
    :maxdepth: 1

    simple_ship_transits
